==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/73/73f05a281642150d67d2d268b0a3554c.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fp-wien/assets/yt-blue.png */
class __TwigTemplate_e9965075ad2fb8c3effc6862a9920b1f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000/\000\000\000sRGB\000\000\000\000eXIfMM\000*\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000J\000\000\000\000\000\000\000R(\000\000\000\000\000\000\000i\000\000\000\000\000\000\000Z\000\000\000\000\000Ϩ\000\000\000Ϩ\000\000\000\000\000\000\000\0000210\000\000\000\000\000\000\000\000\000\0000100\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000IM27\000\000\000\tpHYs\000\000\000\000\000\000\000TiTXtXML:com.adobe.xmp\000\000\000\000\000<x:xmpmeta xmlns:x=\"adobe:ns:meta/\" x:xmptk=\"XMP Core 6.0.0\">
   <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">
      <rdf:Description rdf:about=\"\"
            xmlns:tiff=\"http://ns.adobe.com/tiff/1.0/\"
            xmlns:exif=\"http://ns.adobe.com/exif/1.0/\">
         <tiff:YResolution>511912/7109</tiff:YResolution>
         <tiff:ResolutionUnit>2</tiff:ResolutionUnit>
         <tiff:XResolution>511912/7109</tiff:XResolution>
         <tiff:Orientation>1</tiff:Orientation>
         <exif:PixelXDimension>640</exif:PixelXDimension>
         <exif:ColorSpace>65535</exif:ColorSpace>
         <exif:ComponentsConfiguration>
            <rdf:Seq>
               <rdf:li>1</rdf:li>
               <rdf:li>2</rdf:li>
               <rdf:li>3</rdf:li>
               <rdf:li>0</rdf:li>
            </rdf:Seq>
         </exif:ComponentsConfiguration>
         <exif:ExifVersion>0210</exif:ExifVersion>
         <exif:FlashPixVersion>0100</exif:FlashPixVersion>
         <exif:PixelYDimension>447</exif:PixelYDimension>
      </rdf:Description>
   </rdf:RDF>
</x:xmpmeta>
\tI\000\000IDAT8TnQ=w/H(QP`*\tPP #!TP QP88iP\"Gc83kwfwg<ux>jQԯe\\R&?R1=xtwA7F2|AHz\$?ƇHr*Ӎ^\\@XFG}z?wPY^7x3,WN͹K];h8FVRF\\ȣxxL\t2 s910t\"aFD{\tQ@dPfnIa]%\t::Eg@4x>IRl55OY<aQLO_ǛZhaxpRQ;ґi애2*gEasbyb_.r\$JÜ^I[%q[ń;\\\"&`6w_`g(/cFd,=Pu\tH>B}f.
f
TLm6M3,r6@<athyHFy`B'<t0ҬqSGyv&\000m4}6')...Sto5^I\tꬒŋJ3tgg=#wGttd^^F3W\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fp-wien/assets/yt-blue.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fp-wien/assets/yt-blue.png", "/var/www/mautic-ktn/themes/fp-wien/assets/yt-blue.png");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/73/73f05a281642150d67d2d268b0a3554c.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fp-wien/assets/yt-blue.png */
class __TwigTemplate_e9965075ad2fb8c3effc6862a9920b1f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000/\000\000\000sRGB\000\000\000\000eXIfMM\000*\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000J\000\000\000\000\000\000\000R(\000\000\000\000\000\000\000i\000\000\000\000\000\000\000Z\000\000\000\000\000Ϩ\000\000\000Ϩ\000\000\000\000\000\000\000\0000210\000\000\000\000\000\000\000\000\000\0000100\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000IM27\000\000\000\tpHYs\000\000\000\000\000\000\000TiTXtXML:com.adobe.xmp\000\000\000\000\000<x:xmpmeta xmlns:x=\"adobe:ns:meta/\" x:xmptk=\"XMP Core 6.0.0\">
   <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">
      <rdf:Description rdf:about=\"\"
            xmlns:tiff=\"http://ns.adobe.com/tiff/1.0/\"
            xmlns:exif=\"http://ns.adobe.com/exif/1.0/\">
         <tiff:YResolution>511912/7109</tiff:YResolution>
         <tiff:ResolutionUnit>2</tiff:ResolutionUnit>
         <tiff:XResolution>511912/7109</tiff:XResolution>
         <tiff:Orientation>1</tiff:Orientation>
         <exif:PixelXDimension>640</exif:PixelXDimension>
         <exif:ColorSpace>65535</exif:ColorSpace>
         <exif:ComponentsConfiguration>
            <rdf:Seq>
               <rdf:li>1</rdf:li>
               <rdf:li>2</rdf:li>
               <rdf:li>3</rdf:li>
               <rdf:li>0</rdf:li>
            </rdf:Seq>
         </exif:ComponentsConfiguration>
         <exif:ExifVersion>0210</exif:ExifVersion>
         <exif:FlashPixVersion>0100</exif:FlashPixVersion>
         <exif:PixelYDimension>447</exif:PixelYDimension>
      </rdf:Description>
   </rdf:RDF>
</x:xmpmeta>
\tI\000\000IDAT8TnQ=w/H(QP`*\tPP #!TP QP88iP\"Gc83kwfwg<ux>jQԯe\\R&?R1=xtwA7F2|AHz\$?ƇHr*Ӎ^\\@XFG}z?wPY^7x3,WN͹K];h8FVRF\\ȣxxL\t2 s910t\"aFD{\tQ@dPfnIa]%\t::Eg@4x>IRl55OY<aQLO_ǛZhaxpRQ;ґi애2*gEasbyb_.r\$JÜ^I[%q[ń;\\\"&`6w_`g(/cFd,=Pu\tH>B}f.
f
TLm6M3,r6@<athyHFy`B'<t0ҬqSGyv&\000m4}6')...Sto5^I\tꬒŋJ3tgg=#wGttd^^F3W\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fp-wien/assets/yt-blue.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fp-wien/assets/yt-blue.png", "/var/www/html/mauticGIT-Test/themes/fp-wien/assets/yt-blue.png");
    }
}
